==> u_team_core-common-1.20.1-5.1.4.336-sources.jar: info/u_team/u_team_core/gui/elements/ScrollableList.java <==
package info.u_team.u_team_core.gui.elements;

import com.mojang.blaze3d.platform.GlStateManager.class_4534;
import com.mojang.blaze3d.platform.GlStateManager.class_4535;
import com.mojang.blaze3d.systems.RenderSystem;
import info.u_team.u_team_core.util.RGBA;
import info.u_team.u_team_core.util.RenderUtil;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4280;
import net.minecraft.class_757;

public abstract class ScrollableList<T extends class_4280.class_4281<T>> extends class_4280<T> {
	
	protected int sideDistance;
	
	protected boolean renderTransparentBorder;
	protected float transparentBorderSize;
	
	public ScrollableList(int x, int y, int width, int height, int slotHeight, int sideDistance) {
		super(class_310.method_1551(), 0, 0, 0, 0, slotHeight);
		updateSettings(x, y, width, height);
		this.sideDistance = sideDistance;
		transparentBorderSize = 4;
	}
	
	public ScrollableList(int width, int height, int top, int bottom, int left, int right, int slotHeight, int sideDistance) {
		super(class_310.method_1551(), 0, 0, 0, 0, slotHeight);
		updateSettings(width, height, top, bottom, left, right);
		this.sideDistance = sideDistance;
		transparentBorderSize = 4;
	}
	
	public void updateSettings(int x, int y, int width, int height) {
		updateSettings(width, field_22740.method_22683().method_4502(), y, y + height, x, x + width);
	}
	
	public void updateSettings(int width, int height, int top, int bottom, int left, int right) {
		this.field_22742 = width;
		this.field_22743 = height;
		field_19085 = top;
		field_19086 = bottom;
		field_19088 = left;
		field_19087 = right;
	}
	
	public int getSideDistance() {
		return sideDistance;
	}
	
	public void setSideDistance(int sideDistance) {
		this.sideDistance = sideDistance;
	}
	
	public boolean isRenderTransparentBorder() {
		return renderTransparentBorder;
	}
	
	public void setRenderTransparentBorder(boolean renderTransparentBorder) {
		this.renderTransparentBorder = renderTransparentBorder;
	}
	
	public float getTransparentBorderSize() {
		return transparentBorderSize;
	}
	
	public void setTransparentBorderSize(float transparentBorderSize) {
		this.transparentBorderSize = transparentBorderSize;
	}
	
	@Override
	public int method_25322() {
		return field_22742 - sideDistance;
	}
	
	@Override
	protected int method_25329() {
		return field_19088 + field_22742 - 5;
	}
	
	@Override
	protected void method_25311(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		super.method_25311(guiGraphics, mouseX, mouseY, partialTick);
		
		if (renderTransparentBorder) {
			final class_289 tessellator = class_289.method_1348();
			final class_287 buffer = tessellator.method_1349();
			
			RenderSystem.setShader(class_757::method_34540);
			RenderUtil.setShaderColor(RGBA.BLACK);
			
			RenderSystem.enableBlend();
			RenderSystem.blendFuncSeparate(class_4535.SRC_ALPHA, class_4534.ONE_MINUS_SRC_ALPHA, class_4535.ZERO, class_4534.ONE);
			
			buffer.method_1328(class_293.class_5596.field_27382, class_290.field_1576);
			buffer.method_22912(field_19088, field_19085 + transparentBorderSize, 0).method_1336(0, 0, 0, 0).method_1344();
			buffer.method_22912(field_19087, field_19085 + transparentBorderSize, 0).method_1336(0, 0, 0, 0).method_1344();
			buffer.method_22912(field_19087, field_19085, 0).method_1336(0, 0, 0, 255).method_1344();
			buffer.method_22912(field_19088, field_19085, 0).method_1336(0, 0, 0, 255).method_1344();
			buffer.method_22912(field_19088, field_19086, 0).method_1336(0, 0, 0, 255).method_1344();
			buffer.method_22912(field_19087, field_19086, 0).method_1336(0, 0, 0, 255).method_1344();
			buffer.method_22912(field_19087, field_19086 - transparentBorderSize, 0).method_1336(0, 0, 0, 0).method_1344();
			buffer.method_22912(field_19088, field_19086 - transparentBorderSize, 0).method_1336(0, 0, 0, 0).method_1344();
			
			tessellator.method_1350();
			
			RenderSystem.disableBlend();
			
			RenderUtil.setShaderColor(RGBA.WHITE);
		}
	}
}

==> u_team_core-common-1.20.6-5.4.0.363-sources.jar: info/u_team/u_team_core/gui/elements/ScrollableList.java <==
package info.u_team.u_team_core.gui.elements;

import net.minecraft.class_1921;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4280;

public abstract class ScrollableList<T extends class_4280.class_4281<T>> extends class_4280<T> {
	
	protected int sideDistance;
	
	protected boolean renderTransparentBorder;
	protected int transparentBorderSize;
	
	public ScrollableList(int x, int y, int width, int height, int slotHeight, int sideDistance) {
		super(class_310.method_1551(), width, height, y, slotHeight);
		method_46421(x);
		this.sideDistance = sideDistance;
		transparentBorderSize = 4;
	}
	
	public int getSideDistance() {
		return sideDistance;
	}
	
	public void setSideDistance(int sideDistance) {
		this.sideDistance = sideDistance;
	}
	
	public boolean isRenderTransparentBorder() {
		return renderTransparentBorder;
	}
	
	public void setRenderTransparentBorder(boolean renderTransparentBorder) {
		this.renderTransparentBorder = renderTransparentBorder;
	}
	
	public float getTransparentBorderSize() {
		return transparentBorderSize;
	}
	
	public void setTransparentBorderSize(int transparentBorderSize) {
		this.transparentBorderSize = transparentBorderSize;
	}
	
	@Override
	public int method_25322() {
		return field_22758 - sideDistance;
	}
	
	@Override
	protected int method_25329() {
		return field_22760 + field_22758 - 5;
	}
	
	@Override
	protected void method_25311(class_332 guiGraphics, int mouseX, int mouseY, float partialTick) {
		super.method_25311(guiGraphics, mouseX, mouseY, partialTick);
		
		if (renderTransparentBorder) {
			guiGraphics.method_51740(class_1921.method_51785(), method_46426(), method_46427(), method_55442(), method_46427() + transparentBorderSize, 0xFF000000, 0, 0);
			guiGraphics.method_51740(class_1921.method_51785(), method_46426(), method_55443() - transparentBorderSize, method_55442(), method_55443(), 0, 0xFF000000, 0);
		}
	}
}
